@@ -3,17 +3,18 @@ from graphgallery.data_type import *
 
 # modules
 from graphgallery import nn
+from graphgallery import backend
 from graphgallery import gallery
 from graphgallery import utils
 from graphgallery import sequence
 from graphgallery import data
 from graphgallery import datasets
-from graphgallery import backend
 from graphgallery import functional
+from graphgallery import attack
 
 from .version import __version__
 
 __all__ = [
-    'graphgallery', 'nn', 'gallery', 'utils', 'sequence', 'data', 'datasets',
-    'backend', 'functional', '__version__'
+    "graphgallery", "nn", "gallery", "utils", "sequence", "data", "datasets",
+    "backend", "functional", "attack", "__version__"
 ]
