@@ -1,16 +1,23 @@
-from abc import ABC
 from typing import Any
 
 __all__ = ['Transform', 'NullTransform']
 
-class Transform(ABC):
+
+class Transform:
 
     def __init__(self):
         super().__init__()
 
-    def __call__(self)  -> Any :
+    def __call__(self) -> Any:
         raise NotImplementedError
 
+    def extra_repr(self):
+        return ""
+
+    def __repr__(self) -> str:
+        return f"{self.__class__.__name__}({self.extra_repr()})"
+    __str__ = __repr__
+
 
 class NullTransform(Transform):
     def __init__(self, *args, **kwargs):
@@ -18,6 +25,3 @@ class NullTransform(Transform):
 
     def __call__(self, inputs: Any) -> Any:
         return inputs
-
-    def __repr__(self) -> str:
-        return "NullTransform()"
