@@ -3,20 +3,19 @@ from torch.nn import Module, Parameter
 
 
 class SGConvolution(Module):
-    def __init__(self, order=1, **kwargs):
+    def __init__(self, order=2, **kwargs):
         super().__init__()
         self.order = order
 
-    def forward(self, inputs):
-        x, adj = inputs
+    def forward(self, x, adj):
 
         for _ in range(self.order):
             x = torch.spmm(adj, x)
 
         return x
-    
+
     def reset_parameters(self):
-        ...
-        
-    def __repr__(self):
-        return f"{self.__class__.__name__} (order={self.order})"
+        pass
+
+    def extra_repr(self):
+        return f"order={self.order}"
