@@ -12,10 +12,10 @@ def get_activation(activation):
         raise ValueError("'activation' is expected a 'string', "
                          f"but got {type(activation)}.")
 
-    activation_fn = getattr(F, activation.lower(), 'None')
+    activation_fn = getattr(F, activation, None)
 
     if activation_fn:
         return activation_fn
     else:
         raise KeyError(
-            f"function {activation} not found in torch.nn.functional.")
+            f"function {activation} not found in 'torch.nn.functional'.")
