@@ -14,8 +14,8 @@ class GCN(TorchKeras):
     def __init__(self,
                  in_channels,
                  out_channels,
-                 hiddens=[16],
-                 activations=['relu'],
+                 hids=[16],
+                 acts=['relu'],
                  dropout=0.5,
                  weight_decay=5e-4,
                  lr=0.01,
@@ -24,22 +24,21 @@ class GCN(TorchKeras):
         super().__init__()
 
         paras = []
-        acts = []
+        act_fns = []
         layers = ModuleList()
-
         # use ModuleList to create layers with different size
         inc = in_channels
-        for hidden, activation in zip(hiddens, activations):
+        for hid, act in zip(hids, acts):
             layer = GCNConv(inc,
-                            hidden,
+                            hid,
                             cached=True,
                             bias=use_bias,
                             normalize=False)
             layers.append(layer)
             paras.append(
                 dict(params=layer.parameters(), weight_decay=weight_decay))
-            acts.append(get_activation(activation))
-            inc = hidden
+            act_fns.append(get_activation(act))
+            inc = hid
 
         layer = GCNConv(inc,
                         out_channels,
@@ -50,19 +49,18 @@ class GCN(TorchKeras):
         # do not use weight_decay in the final layer
         paras.append(dict(params=layer.parameters(), weight_decay=0.))
 
-        self.acts = acts
+        self.act_fns = act_fns
         self.layers = layers
         self.dropout = Dropout(dropout)
         self.compile(loss=torch.nn.CrossEntropyLoss(),
                      optimizer=optim.Adam(paras, lr=lr),
                      metrics=[Accuracy()])
 
-    def forward(self, inputs):
-        x, edge_index, edge_weight, idx = inputs
+    def forward(self, x, edge_index, edge_weight=None):
 
-        for layer, act in zip(self.layers, self.acts):
+        for layer, act in zip(self.layers, self.act_fns):
             x = act(layer(x, edge_index, edge_weight))
             x = self.dropout(x)
 
         x = self.layers[-1](x, edge_index, edge_weight)
-        return x[idx]
+        return x
