@@ -1,7 +1,6 @@
 import torch
 import torch.nn.functional as F
-
-from torch.nn import Module, ModuleList, Dropout
+import torch.nn as nn
 from torch import optim
 
 from graphgallery.nn.models import TorchKeras
@@ -13,9 +12,9 @@ class GAT(TorchKeras):
     def __init__(self,
                  in_channels,
                  out_channels,
-                 hiddens=[8],
-                 n_heads=[8],
-                 activations=['elu'],
+                 hids=[8],
+                 num_heads=[8],
+                 acts=['elu'],
                  dropout=0.6,
                  weight_decay=5e-4,
                  lr=0.01,
@@ -23,23 +22,22 @@ class GAT(TorchKeras):
 
         super().__init__()
 
-        layers = ModuleList()
+        layers = nn.ModuleList()
         paras = []
 
         inc = in_channels
         pre_head = 1
-        for hidden, n_head, activation in zip(hiddens, n_heads, activations):
+        for hid, num_head, act in zip(hids, num_heads, acts):
             layer = SparseGraphAttention(inc * pre_head,
-                                         hidden,
-                                         activation=activation,
-                                         attn_heads=n_head,
+                                         hid,
+                                         activation=act,
+                                         attn_heads=num_head,
                                          reduction='concat',
                                          use_bias=use_bias)
             layers.append(layer)
-            paras.append(
-                dict(params=layer.parameters(), weight_decay=weight_decay))
-            inc = hidden
-            pre_head = n_head
+            paras.append(dict(params=layer.parameters(), weight_decay=weight_decay))
+            inc = hid
+            pre_head = num_head
 
         layer = SparseGraphAttention(inc * pre_head,
                                      out_channels,
@@ -51,16 +49,15 @@ class GAT(TorchKeras):
         paras.append(dict(params=layer.parameters(), weight_decay=0.))
 
         self.layers = layers
-        self.dropout = Dropout(dropout)
+        self.dropout = nn.Dropout(dropout)
         self.compile(loss=torch.nn.CrossEntropyLoss(),
                      optimizer=optim.Adam(paras, lr=lr),
                      metrics=[Accuracy()])
 
-    def forward(self, inputs):
-        x, adj, idx = inputs
+    def forward(self, x, adj):
 
         for layer in self.layers:
             x = self.dropout(x)
-            x = layer([x, adj])
+            x = layer(x, adj)
 
-        return x[idx]
+        return x
