@@ -13,30 +13,30 @@ class SGC(TorchKeras):
     def __init__(self,
                  in_channels,
                  out_channels,
-                 hiddens=[],
-                 activations=[],
+                 hids=[],
+                 acts=[],
                  dropout=0.5,
                  weight_decay=5e-5,
                  lr=0.2,
                  use_bias=False):
         super().__init__()
 
-        if len(hiddens) != len(activations):
+        if len(hids) != len(acts):
             raise RuntimeError(
-                f"Arguments 'hiddens' and 'activations' should have the same length."
+                f"Arguments 'hids' and 'acts' should have the same length."
                 " Or you can set both of them to `[]`.")
 
         layers = ModuleList()
-        acts = []
+        acts_fn = []
         paras = []
         inc = in_channels
-        for hidden, activation in zip(hiddens, activations):
-            layer = Linear(inc, hidden, bias=use_bias)
+        for hid, act in zip(hids, acts):
+            layer = Linear(inc, hid, bias=use_bias)
             paras.append(
                 dict(params=layer.parameters(), weight_decay=weight_decay))
             layers.append(layer)
-            inc = hidden
-            acts.append(get_activation(activation))
+            inc = hid
+            acts_fn.append(get_activation(act))
 
         layer = Linear(inc, out_channels, bias=use_bias)
         layers.append(layer)
@@ -44,7 +44,7 @@ class SGC(TorchKeras):
                           weight_decay=weight_decay))
 
         self.layers = layers
-        self.acts = acts
+        self.acts_fn = acts_fn
         self.dropout = Dropout(dropout)
         self.compile(loss=torch.nn.CrossEntropyLoss(),
                      optimizer=optim.Adam(paras, lr=lr),
@@ -53,7 +53,7 @@ class SGC(TorchKeras):
     def forward(self, inputs):
         x = inputs
 
-        for layer, act in zip(self.layers, self.acts):
+        for layer, act in zip(self.layers[:-1], self.acts_fn):
             x = self.dropout(x)
             x = act(layer(x))
 
