@@ -5,14 +5,14 @@ from tensorflow.keras import regularizers
 from tensorflow.keras.losses import SparseCategoricalCrossentropy
 
 from graphgallery.nn.layers.tensorflow import GraphEdgeConvolution, Gather
-from graphgallery import floatx, intx
 from graphgallery.nn.models import TFKeras
+from graphgallery import floatx, intx
 
 
 class EdgeGCN(TFKeras):
 
     def __init__(self, in_channels, out_channels,
-                 hiddens=[16], activations=['relu'], dropout=0.5,
+                 hids=[16], acts=['relu'], dropout=0.5,
                  weight_decay=5e-4, lr=0.01, use_bias=False):
 
         _intx = intx()
@@ -23,21 +23,18 @@ class EdgeGCN(TFKeras):
                            name='edge_index')
         edge_weight = Input(batch_shape=[None], dtype=_floatx,
                             name='edge_weight')
-        index = Input(batch_shape=[None],
-                      dtype=_intx, name='node_index')
 
         h = x
-        for hidden, activation in zip(hiddens, activations):
-            h = GraphEdgeConvolution(hidden, use_bias=use_bias,
-                                     activation=activation,
+        for hid, act in zip(hids, acts):
+            h = GraphEdgeConvolution(hid, use_bias=use_bias,
+                                     activation=act,
                                      kernel_regularizer=regularizers.l2(weight_decay))([h, edge_index, edge_weight])
 
             h = Dropout(rate=dropout)(h)
 
         h = GraphEdgeConvolution(out_channels, use_bias=use_bias)(
             [h, edge_index, edge_weight])
-        output = Gather()([h, index])
 
-        super().__init__(inputs=[x, edge_index, edge_weight, index], outputs=output)
+        super().__init__(inputs=[x, edge_index, edge_weight], outputs=h)
         self.compile(loss=SparseCategoricalCrossentropy(from_logits=True),
                      optimizer=Adam(lr=lr), metrics=['accuracy'])
