@@ -4,7 +4,8 @@ from tensorflow.keras.optimizers import Adam
 from tensorflow.keras import regularizers
 from tensorflow.keras.losses import SparseCategoricalCrossentropy
 
-from graphgallery.nn.layers.tensorflow import GraphConvolution, Gather
+
+from graphgallery.nn.layers.tensorflow import GraphConvolution
 from graphgallery import floatx, intx
 from graphgallery.nn.models import TFKeras
 
@@ -12,8 +13,8 @@ from graphgallery.nn.models import TFKeras
 class GCN(TFKeras):
 
     def __init__(self, in_channels, out_channels,
-                 hiddens=[16],
-                 activations=['relu'],
+                 hids=[16],
+                 acts=['relu'],
                  dropout=0.5,
                  weight_decay=5e-4,
                  lr=0.01, use_bias=False,
@@ -23,37 +24,35 @@ class GCN(TFKeras):
                   dtype=floatx(), name='node_attr')
         adj = Input(batch_shape=[None, None], dtype=floatx(),
                     sparse=True, name='adj_matrix')
-        index = Input(batch_shape=[None], dtype=intx(), name='node_index')
 
         h = x
-        for hidden, activation in zip(hiddens, activations):
-            h = GraphConvolution(hidden, use_bias=use_bias,
-                                 activation=activation,
+        for hid, act in zip(hids, acts):
+            h = GraphConvolution(hid, use_bias=use_bias,
+                                 activation=act,
                                  kernel_regularizer=regularizers.l2(weight_decay))([h, adj])
 
             h = Dropout(rate=dropout)(h)
 
         h = GraphConvolution(out_channels, use_bias=use_bias)([h, adj])
-        h = Gather()([h, index])
 
-        super().__init__(inputs=[x, adj, index], outputs=h)
+        super().__init__(inputs=[x, adj], outputs=h)
         self.compile(loss=SparseCategoricalCrossentropy(from_logits=True),
                      optimizer=Adam(lr=lr), metrics=['accuracy'],
                      experimental_run_tf_function=experimental_run_tf_function)
 
 # class GCN(Model):
 
-#     def __init__(self, hiddens,
-#                  out_channels, activations=['relu'],
+#     def __init__(self, hids,
+#                  out_channels, acts=['relu'],
 #                  weight_decay=5e-4, dropout=0.5,
 #                  lr=0.01, use_bias=False):
 
 #         super().__init__()
 
 #         self.GNN_layers = []
-#         for hidden, activation, weight_decay in zip(hiddens, activations, weight_decay):
-#             layer = GraphConvolution(hidden, use_bias=use_bias,
-#                                          activation=activation,
+#         for hid, act, weight_decay in zip(hids, acts, weight_decay):
+#             layer = GraphConvolution(hid, use_bias=use_bias,
+#                                          activation=act,
 #                                          kernel_regularizer=regularizers.l2(weight_decay))
 
 #             self.GNN_layers.append(layer)
