@@ -5,7 +5,7 @@ from tensorflow.keras.optimizers import Adam
 from tensorflow.keras import regularizers
 from tensorflow.keras.losses import SparseCategoricalCrossentropy
 
-from graphgallery.nn.layers.tensorflow import GaussionConvolution_F, GaussionConvolution_D, Sample, Gather
+from graphgallery.nn.layers.tensorflow import GaussionConvolution_F, GaussionConvolution_D, Sample
 from graphgallery import floatx, intx
 from graphgallery.nn.models import TFKeras
 
@@ -13,8 +13,8 @@ from graphgallery.nn.models import TFKeras
 class RobustGCN(TFKeras):
 
     def __init__(self, in_channels, out_channels,
-                 hiddens=[64],
-                 activations=['relu'],
+                 hids=[64],
+                 acts=['relu'],
                  dropout=0.5,
                  weight_decay=5e-4,
                  lr=0.01, kl=5e-4, gamma=1.,
@@ -27,13 +27,12 @@ class RobustGCN(TFKeras):
                      sparse=True, name='adj_matrix_1'),
                Input(batch_shape=[None, None], dtype=_floatx, sparse=True,
                      name='adj_matrix_2')]
-        index = Input(batch_shape=[None], dtype=intx(), name='node_index')
 
         h = x
-        if hiddens:
-            mean, var = GaussionConvolution_F(hiddens[0], gamma=gamma,
+        if hids:
+            mean, var = GaussionConvolution_F(hids[0], gamma=gamma,
                                               use_bias=use_bias,
-                                              activation=activations[0],
+                                              activation=acts[0],
                                               kernel_regularizer=regularizers.l2(weight_decay))([h, *adj])
             if kl:
                 KL_divergence = 0.5 * \
@@ -45,10 +44,10 @@ class RobustGCN(TFKeras):
                 kl_loss = kl * KL_divergence
 
         # additional layers (usually unnecessay)
-        for hidden, activation in zip(hiddens[1:], activations[1:]):
+        for hid, act in zip(hids[1:], acts[1:]):
 
             mean, var = GaussionConvolution_D(
-                hidden, gamma=gamma, use_bias=use_bias, activation=activation)([mean, var, *adj])
+                hid, gamma=gamma, use_bias=use_bias, activation=act)([mean, var, *adj])
             mean = Dropout(rate=dropout)(mean)
             var = Dropout(rate=dropout)(var)
 
@@ -56,11 +55,10 @@ class RobustGCN(TFKeras):
             out_channels, gamma=gamma, use_bias=use_bias)([mean, var, *adj])
 
         h = Sample()([mean, var])
-        h = Gather()([h, index])
 
-        super().__init__(inputs=[x, *adj, index], outputs=h)
+        super().__init__(inputs=[x, *adj], outputs=h)
         self.compile(loss=SparseCategoricalCrossentropy(from_logits=True),
                      optimizer=Adam(lr=lr), metrics=['accuracy'])
 
-        if hiddens and kl:
+        if hids and kl:
             self.add_loss(kl_loss)
