@@ -3,7 +3,7 @@ import numpy as np
 import tensorflow as tf
 import scipy.sparse as sp
 
-from graphgallery.sequence.base_sequence import Sequence
+from .base_sequence import Sequence
 
 
 class MiniBatchSequence(Sequence):
@@ -12,24 +12,25 @@ class MiniBatchSequence(Sequence):
         self,
         x,
         y,
+        out_weight=None,
         shuffle=False,
         batch_size=1,
         *args, **kwargs
     ):
         super().__init__(*args, **kwargs)
         assert batch_size == 1
-        self.x, self.y = self.astensors(x, y)
-        self.n_batches = len(self.x)
+        self.n_batches = len(x)
         self.shuffle = shuffle
-        self.batch_size = batch_size
         self.indices = list(range(self.n_batches))
+        self.batch_size = batch_size
+        self.x, self.y, self.out_weight = self.astensors(x, y, out_weight)
 
     def __len__(self):
         return self.n_batches
 
     def __getitem__(self, index):
         idx = self.indices[index]
-        return self.x[idx], self.y[idx]
+        return self.x[idx], self.y[idx], self.out_weight[idx]
 
     def on_epoch_end(self):
         if self.shuffle:
@@ -48,7 +49,8 @@ class SAGEMiniBatchSequence(Sequence):
         self,
         x,
         y=None,
-        n_samples=[5, 5],
+        out_weight=None,
+        num_samples=[5, 5],
         shuffle=False,
         batch_size=512,
         *args, **kwargs
@@ -60,7 +62,7 @@ class SAGEMiniBatchSequence(Sequence):
         self.shuffle = shuffle
         self.batch_size = batch_size
         self.indices = np.arange(len(self.batch_nodes))
-        self.n_samples = n_samples
+        self.num_samples = num_samples
 
         self.node_attr = self.astensor(self.node_attr)
 
@@ -75,15 +77,18 @@ class SAGEMiniBatchSequence(Sequence):
             idx = slice(index * self.batch_size, (index + 1) * self.batch_size)
 
         nodes_input = [self.batch_nodes[idx]]
-        for n_sample in self.n_samples:
+        for num_sample in self.num_samples:
             neighbors = sample_neighbors(
-                self.adj_matrix, nodes_input[-1], n_sample).ravel()
+                self.adj_matrix, nodes_input[-1], num_sample).ravel()
             nodes_input.append(neighbors)
 
         y = self.y[idx] if self.y is not None else None
 
         return self.astensors([self.node_attr, *nodes_input], y)
 
+    def on_epoch_end(self):
+        pass
+
     def on_epoch_end(self):
         if self.shuffle:
             self._shuffle_batches()
@@ -95,9 +100,9 @@ class SAGEMiniBatchSequence(Sequence):
         random.shuffle(self.indices)
 
 
-def sample_neighbors(adj_matrix, nodes, n_neighbors):
+def sample_neighbors(adj_matrix, nodes, num_neighbors):
     np.random.shuffle(adj_matrix.T)
-    return adj_matrix[nodes, :n_neighbors]
+    return adj_matrix[nodes, :num_neighbors]
 
 
 class FastGCNBatchSequence(Sequence):
@@ -168,6 +173,9 @@ class FastGCNBatchSequence(Sequence):
 
         return (node_attr, adj_matrix), y
 
+    def on_epoch_end(self):
+        pass
+
     def on_epoch_end(self):
         if self.shuffle:
             self._shuffle_batches()
