@@ -7,7 +7,7 @@ def tqdm_clear(*args, **kwargs):
 
 
 def tqdm(*args, **kwargs):
-    """decorator of tqdm, to avoid some errors if tqdm 
+    """Decorator of tqdm, to avoid some errors if tqdm 
     terminated unexpectedly
 
     Returns
@@ -20,4 +20,5 @@ def tqdm(*args, **kwargs):
             tqdm_base._decr_instances(instance)
     return tqdm_base(*args, **kwargs)
 
+
 tqdm.__doc__ = tqdm_base.__doc__ + tqdm_base.__init__.__doc__
